from goldpot import *

api_key = "<enter you api key>"

def search_sample(api_key):
    gp = Goldpot(api_key)
    docs = ['I like pizza.', 'Python is a scripting language.', 'Socrates is an ancient philosopher.']
    si = SearchInput(query="I like beer.", docs=docs, max_chars=8000)
    out = gp.search(si)
    print(out.scores)
    print(out.scores_sorted)


if __name__ == '__main__':
    search_sample(api_key)


from dataclasses import dataclass, asdict
from typing import Iterable

import openai
from openai.openai_object import OpenAIObject

from goldpot import DefaultConfig
from goldpot.CompletionEnginesConfig import CompletionEngineConfig
from goldpot.Model import CompletionInput, CompletionOutput, SearchInput, SearchOutput


@dataclass
class Goldpot:
    api_key: str
    completion_engine_config: CompletionEngineConfig = DefaultConfig.completion_engine_config
    search_engine_config: str = DefaultConfig.search_engine_config

    def __post_init__(self):
        openai.api_key = self.api_key

    def complete_(self, prompt: str) -> OpenAIObject:
        return openai.Completion.create(prompt=prompt, **asdict(self.completion_engine_config))

    def complete(self, input: CompletionInput) -> CompletionOutput:
        prompts = input.get_prompts()
        return CompletionOutput([self.complete_(prompt) for prompt in prompts], prompts)

    def search_(self, query: str, docs: Iterable[str]) -> OpenAIObject:
        return openai.Engine(str(self.search_engine_config)).search(documents=docs, query=query)

    def search(self, input: SearchInput) -> SearchOutput:
        return SearchOutput(
            #[self.search_(q := query_docs[0], ds := query_docs[1]) for query_docs in input.get_docs()], input.docs)
            # Python 3.7:
            [self.search_(query_docs[0], query_docs[1]) for query_docs in input.get_docs()], input.docs)



from dataclasses import dataclass, field
from typing import Iterable
from pathlib import Path

from yamldataclassconfig import YamlDataClassConfig


@dataclass
class CompletionPromptConfig(YamlDataClassConfig):
    start: str = ""
    samples: Iterable[str] = field(
        default=None,
        metadata={'dataclasses_json': {'mm_field': Iterable[str]}})

    def read(self, path: str):
        self.load(Path(path))
        return self


from goldpot.DefaultConfig import Engines

from goldpot import *

api_key = "<enter you api key>"

def completion_sample(api_key: str):
    cec = CompletionEngineConfig(engine=Engines.ADA, max_tokens=256, temperature=0.0, top_p=0.0, n=1, stream=False,
                                 logprobs=None, echo=False, stop=['####'], presence_penalty=0.0, frequency_penalty=0.0, best_of=1)

    gp = Goldpot(api_key, completion_engine_config=cec)
    # samples = ["Begin: I like\nEnd: beer.", "Begin: I like\nEnd: soccer.", "Begin: I like\nEnd: pizza."]
    samples_ci = SamplesCompletionInput(prompt_config=CompletionPromptConfig().read("conf/sample_prompt_config.yml"),
                                        end="Begin: I like\nEnd:",
                                        max_chars=7500)
    out: CompletionOutput = gp.complete(samples_ci)

    # string_ci = StringCompletionInput(text="Foo Bar!", max_chars=4)
    # out: CompletionOutput = gp.complete(string_ci)

    print(out)


if __name__ == '__main__':
    completion_sample(api_key)




from enum import Enum, auto

from goldpot.CompletionEnginesConfig import CompletionEnginesConfigReader, CompletionEngineConfig

class Engines(Enum):
    ADA = auto()
    BABBAGE = auto()
    CURIE = auto()
    DAVINCI = auto()
    INSTRUCT_CURIE_BETA = auto()
    INSTRUCT_DAVINCI_BETA = auto()

    def __str__(self):
        return self.name.lower().replace('_', '-')

class DefaultConfig:
    max_chars: int = 7500
    completion_engine_config: CompletionEngineConfig = CompletionEnginesConfigReader().read("conf/sample_engines_config.yml").get("TST")
    search_engine_config = Engines.ADA


import setuptools

with open("README_PyPI.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setuptools.setup(
    name="goldpot",
    version="0.0.3.1",
    author="Sebastian Senge",
    author_email="ssenge.public@gmail.com",
    description="A thin convenience layer on top of OpenAI's GPT-3 Python library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ssenge/Goldpot",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)



from dataclasses import dataclass, field
from functools import reduce
from typing import Iterable, List, Optional, Dict
from pathlib import Path

from dataclasses_json import DataClassJsonMixin
from yamldataclassconfig import YamlDataClassConfig


@dataclass
class CompletionEngineConfig(DataClassJsonMixin):
    engine: str
    max_tokens: int
    temperature: float
    top_p: float
    n: int
    stream: bool
    logprobs: Optional[int]
    echo: bool
    stop: Optional[List[str]]
    presence_penalty: float
    frequency_penalty: float
    best_of: int
    #logit_bias: Optional[Dict[str, int]]

    def __post_init__(self):
        if not isinstance(self.engine, str):
            self.engine = str(self.engine)


@dataclass
class CompletionEnginesConfigReader(YamlDataClassConfig):
    configs: List[Dict[str, CompletionEngineConfig]] = field(
        default=None,
        metadata={'dataclasses_json': {'mm_field': List[Dict[str, CompletionEngineConfig]]}})

    def read(self, path: str):
        self.load(Path(path))
        self.configs = reduce(lambda d1, d2: {**d1, **d2}, self.configs) # TODO: curerntly using Python 3.8, >=3.9 has d1|d2
        return self

    def get(self, handle: str):
        return self.configs.get(handle, None)

